@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.001003'; # VERSION
+our $VERSION = '0.001004'; # VERSION
 
 use Moose;
 with qw(
@@ -56,8 +56,6 @@ sub configure {
 		Test::Portability
 		Test::Perl::Critic
 
-		ContributorsFromGit
-
 		Test::UnusedVars
 		Test::CPAN::Meta::JSON
 		Test::DistManifest
@@ -67,6 +65,7 @@ sub configure {
 
 		CheckChangesHasContent
 		Git::Remote::Check
+		Git::Contributors
 	));
 
 	push @plugins, (
@@ -96,7 +95,7 @@ Dist::Zilla::PluginBundle::Author::XENO - Author Bundle for Caleb Cushing
 
 =head1 VERSION
 
-version 0.001003
+version 0.001004
 
 =head1 SYNOPSIS
 
@@ -115,7 +114,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Caleb Cushing.
+This software is Copyright (c) 2015 by Caleb Cushing.
 
 This is free software, licensed under:
 
